@@ -29,8 +29,9 @@ import pickle
 from PIL import Image
 import re
 import urllib2
+import socket
 
-__version__ = '0.0.27'
+__version__ = '0.0.28'
 
 def write_report(error):
     filename = os.path.join(CACHE_PATH,'crash_report')
@@ -65,7 +66,7 @@ KHWEETEUR_IDENTICA_CONSUMER_SECRET = '236fa46bf3f65fabdb1fd34d63c26d28'
 SCREENNAMEROLE = 20
 
 class KhweeteurDBus(dbus.service.Object):
-
+    '''DBus Object handle dbus callback'''
     @dbus.service.method("net.khertan.khweeteur",
                          in_signature='', out_signature='')
     def show(self):
@@ -84,6 +85,7 @@ class KhweeteurDBus(dbus.service.Object):
         self.win = win
         
 class KhweeteurNotification(QObject):
+    '''Notification class interface'''
     def __init__(self):
         QObject.__init__(self)
         self.m_bus = dbus.SystemBus()
@@ -127,8 +129,9 @@ class KhweeteurNotification(QObject):
                           'count':count},
                           -1
                           )
+                          
 class KhweeteurActionWorker(QThread):
-
+    '''ActionWorker : Post tweet in background'''
     def __init__(self, parent = None, action=None, data=None, data2=None, data3=None):
         QThread.__init__(self, parent)
         self.settings = QSettings()
@@ -194,7 +197,7 @@ class KhweeteurActionWorker(QThread):
 #                self.tb_text.setText('')
 #                self.tb_text_replyid = 0
 #                self.tb_text_replytext = ''
-        except (twitter.TwitterError,StandardError,urllib2.HTTPError, urllib2.httplib.BadStatusLine),e:
+        except (twitter.TwitterError,StandardError,urllib2.HTTPError, urllib2.httplib.BadStatusLine, socket.timeout, socket.sslerror),e:
             if type(e)==twitter.TwitterError:
 #                self.notifications.warn('Send tweet failed : '+(e.message))
                 self.emit(SIGNAL("warn(PyQt_PyObject)"),e.message)
@@ -206,7 +209,7 @@ class KhweeteurActionWorker(QThread):
 
                           
 class KhweeteurWorker(QThread):
-
+    ''' Thread to Refresh in background '''
     def __init__(self, parent = None, search_keyword=None):
         QThread.__init__(self, parent)
         self.settings = QSettings()
@@ -217,7 +220,7 @@ class KhweeteurWorker(QThread):
         if self.search_keyword==None:
             self.refresh()
         else:
-            print 'Worker Refresh search : '+self.search_keyword 
+#            print 'Worker Refresh search : '+self.search_keyword 
             self.refresh_search()
 
     def testCacheFolders(self):
@@ -245,7 +248,7 @@ class KhweeteurWorker(QThread):
                     #im.save(os.path.splitext(cache)[0]+'.png', 'PNG', transparency=transparency)
                     im.save(os.path.splitext(cache)[0]+'.png', 'PNG')
 #                    print os.path.splitext(cache)[0]+'.png'
-                except (StandardError,urllib2.HTTPError, urllib2.httplib.BadStatusLine),e:
+                except (StandardError,urllib2.HTTPError, urllib2.httplib.BadStatusLine, socket.timeout, socket.sslerror),e:
                     print 'DownloadProfileImage Error : ',e
         
     def refresh_search(self):
@@ -271,8 +274,7 @@ class KhweeteurWorker(QThread):
         except twitter.TwitterError,e:
             print 'Error during refresh : ',e.message
             self.emit(SIGNAL("info(PyQt_PyObject)"),e.message)
-        except (StandardError,urllib2.HTTPError, urllib2.httplib.BadStatusLine),e:
-            print 'Error during refresh : ',e.message
+        except (StandardError,urllib2.HTTPError, urllib2.httplib.BadStatusLine, socket.timeout, socket.sslerror),e:
             self.emit(SIGNAL("info(PyQt_PyObject)"),'A network error occur')
 
         try:
@@ -289,7 +291,7 @@ class KhweeteurWorker(QThread):
         except twitter.TwitterError,e:
             print 'Error during refresh : ',e.message
             self.emit(SIGNAL("info(PyQt_PyObject)"),e.message)
-        except (StandardError,urllib2.HTTPError, urllib2.httplib.BadStatusLine),e:
+        except (StandardError,urllib2.HTTPError, urllib2.httplib.BadStatusLine, socket.timeout, socket.sslerror),e:
             print 'Error during refresh : ',e.message
             self.emit(SIGNAL("info(PyQt_PyObject)"),'A network error occur')
 
@@ -316,7 +318,7 @@ class KhweeteurWorker(QThread):
                         access_token_key=str(self.settings.value("twitter_access_token_key").toString()), \
                         access_token_secret=str(self.settings.value("twitter_access_token_secret").toString()))
                 api.SetUserAgent('Khweeteur/%s' % (__version__))
-                for status in api.GetFriendsTimeline(since_id=self.settings.value("twitter_last_id").toString()):
+                for status in api.GetFriendsTimeline(since_id=self.settings.value("twitter_last_id").toString(), retweets=True):
                     downloadProfileImage(status)
                     mlist.append((status.created_at_in_seconds,status))
                     if status.GetId() > twitter_last_id:
@@ -340,11 +342,15 @@ class KhweeteurWorker(QThread):
                     mlist.append((status.created_at_in_seconds,status))                        
                     if status.GetId() > twitter_last_id:
                             twitter_last_id = status.GetId()
-
+                            
+                #Moved here to avoid partial refresh
+                if (twitter_last_id != None):
+                    self.settings.setValue('twitter_last_id',twitter_last_id)
+                    
         except twitter.TwitterError,e:
             print 'Error during twitter refresh : ',e.message
             self.emit(SIGNAL("info(PyQt_PyObject)"),e.message)
-        except (StandardError,urllib2.HTTPError, urllib2.httplib.BadStatusLine),e:
+        except (StandardError,urllib2.HTTPError, urllib2.httplib.BadStatusLine, socket.timeout, socket.sslerror),e:
             print 'Error during twitter refresh : ',e
             self.emit(SIGNAL("info(PyQt_PyObject)"),'A network error occur')
 
@@ -381,20 +387,18 @@ class KhweeteurWorker(QThread):
                     if status.GetId() > identica_last_id:
                         identica_last_id = status.GetId()
                     downloadProfileImage(status)
-                    mlist.append((status.created_at_in_seconds,status))                        
+                    mlist.append((status.created_at_in_seconds,status))                   
+                if (identica_last_id != None):
+                    self.settings.setValue('identica_last_id',identica_last_id)      
         except twitter.TwitterError,e:
             print 'Error during identi.ca refresh: ',e.message
             self.emit(SIGNAL("info(PyQt_PyObject)"),e.message)
-        except (StandardError,urllib2.HTTPError, urllib2.httplib.BadStatusLine),e:
+        except (StandardError,urllib2.HTTPError, urllib2.httplib.BadStatusLine, socket.timeout, socket.sslerror),e:
             print 'Error during identi.ca refresh : ',e
             self.emit(SIGNAL("info(PyQt_PyObject)"),'A network error occur')
                 
 
         if len(mlist)>0:
-            if (twitter_last_id != None):
-                self.settings.setValue('twitter_last_id',twitter_last_id)
-            if (identica_last_id != None):
-                self.settings.setValue('identica_last_id',identica_last_id)
             mlist.sort()            
             self.emit(SIGNAL("newStatuses(PyQt_PyObject)"),mlist)
                         
@@ -522,16 +526,16 @@ class KhweetsModel(QAbstractListModel):
     def setTweets(self,mlist):
         try:
             if len(mlist)>0:
-                if type(mlist[0])==tuple:
-                    if len(mlist[0])==6:
-                        self._items = mlist
-                        self._new_counter = 0
-                        QObject.emit(self, SIGNAL("dataChanged(const QModelIndex&, const QModelIndex &)"), self.createIndex(0,0), self.createIndex(0,len(self._items)))
-                        return True
-                    else:
-                        print 'Wrong cache format'
-                        write_report("%s Version %s\nOld cache format : %s\n" % ('Khweeteur', __version__, ''))
-                        KhweeteurNotification().info('Old cache format. Reinit cache.')            
+                #if type(mlist[0])==tuple:
+                #    if len(mlist[0])==6:
+                self._items = mlist
+                self._new_counter = 0
+                QObject.emit(self, SIGNAL("dataChanged(const QModelIndex&, const QModelIndex &)"), self.createIndex(0,0), self.createIndex(0,len(self._items)))
+                return True
+                 #   else:
+                 #       print 'Wrong cache format'
+                 #       write_report("%s Version %s\nOld cache format : %s\n" % ('Khweeteur', __version__, ''))
+                 #       KhweeteurNotification().info('Old cache format. Reinit cache.')            
         except StandardError,err:
             KhweeteurNotification().info('Wrong cache format. Reinit cache.')
             write_report("%s Version %s\nWrong cache format : %s\n" % ('Khweeteur', __version__, err))
@@ -585,8 +589,8 @@ class KhweetsModel(QAbstractListModel):
                         if not path.endswith('.png'):
                             path = os.path.splitext(path)[0]+'.png'
                         pix = (QPixmap(path)) #.scaled(50,50)
-                        if pix.isNull():
-                            print path
+#                        if pix.isNull():
+#                            print path
                         self._avatars[item[4]] = (pix)
                 except StandardError, err:
                     print 'error on loading avatar :',err 
@@ -776,6 +780,190 @@ class WhiteCustomDelegate(QStyledItemDelegate):
             painter.drawText(option.rect.adjusted(70,0,-2,0),  int(Qt.AlignBottom) | int(Qt.AlignLeft), screenname);
 
         painter.restore()
+
+class CoolWhiteCustomDelegate(QStyledItemDelegate):
+    '''Delegate to do custom draw of the items'''
+
+    def __init__(self, parent):
+        '''Initialization'''
+        QStyledItemDelegate.__init__(self, parent)
+        self.show_avatar = True
+        self.show_screenname = True
+        self.show_timestamp = True
+
+        self.user_color = QColor('#3399cc')
+        self.time_color = QColor('#94a1a7')
+        self.bg_color = QColor('#edf1f2')
+        self.bg_alternate_color = QColor('#e6eaeb')
+        self.text_color = QColor('#444444')
+        self.separator_color = QColor('#c8cdcf')
+                
+        self.fm = None
+        
+        self.normFont = None
+        self.miniFont = None
+
+    def sizeHint (self, option, index):
+        '''Custom size calculation of our items'''
+        size = QStyledItemDelegate.sizeHint(self, option, index)
+        tweet = index.data(Qt.DisplayRole).toString()
+        #One time is enought sizeHint need to be fast
+        if self.fm == None:
+            self.fm = QFontMetrics(option.font)
+        height = self.fm.boundingRect(0,0,option.rect.width()-75,800, int(Qt.AlignTop) | int(Qt.AlignLeft) | int(Qt.TextWordWrap), tweet).height()
+        if height<40:
+            height=40        
+        return QSize(size.width(), height+44)
+        
+
+    def paint(self, painter, option, index):
+        '''Paint our tweet'''
+        self.fm = QFontMetrics(option.font)
+
+        model = index.model()
+        tweet = index.data(Qt.DisplayRole).toString()
+        
+        #Instantiate font only one time !
+        if self.normFont == None:
+            self.normFont = QFont(option.font)
+            self.miniFont = QFont(option.font)
+            self.miniFont.setPointSizeF(option.font.pointSizeF() * 0.80)            
+        
+        painter.save()
+        
+        # Draw alternate ?
+        if (index.row()%2)==0:
+            painter.fillRect(option.rect, self.bg_color)
+        else:
+            painter.fillRect(option.rect, self.bg_alternate_color)            
+
+        # highlight selected items
+        if option.state & QStyle.State_Selected: 
+            painter.fillRect(option.rect, option.palette.highlight());
+                    
+        # Draw icon
+        if self.show_avatar:
+            icon = index.data(Qt.DecorationRole).toPyObject();
+            if icon != None:
+                x1,y1,x2,y2 = option.rect.getCoords()
+                painter.drawPixmap(x1+10,y1+10,50,50,icon)
+                                                
+        # Draw tweet
+        painter.setPen(self.text_color)
+        new_rect = painter.drawText(option.rect.adjusted(int(self.show_avatar)*70,5,0,0),  int(Qt.AlignTop) | int(Qt.AlignLeft) | int(Qt.TextWordWrap), tweet); 
+                
+        # Draw Timeline
+        if self.show_timestamp:
+            time = index.data(Qt.ToolTipRole).toString();
+            painter.setFont(self.miniFont)
+            painter.setPen(self.time_color)
+            painter.drawText(option.rect.adjusted(70,10,-10,-9),  int(Qt.AlignBottom) | int(Qt.AlignRight), time);
+
+        # Draw screenname
+        if self.show_screenname:
+            screenname = index.data(SCREENNAMEROLE).toString();
+            painter.setFont(self.miniFont)
+            painter.setPen(self.user_color)
+            painter.drawText(option.rect.adjusted(70,10,-10,-9),  int(Qt.AlignBottom) | int(Qt.AlignLeft), screenname);
+
+        # Draw line
+        painter.setPen(self.separator_color)
+        x1,y1,x2,y2 = option.rect.getCoords()
+        painter.drawLine(x1,y2,x2,y2) 
+
+        painter.restore()
+
+class CoolGrayCustomDelegate(QStyledItemDelegate):
+    '''Delegate to do custom draw of the items'''
+
+    def __init__(self, parent):
+        '''Initialization'''
+        QStyledItemDelegate.__init__(self, parent)
+        self.show_avatar = True
+        self.show_screenname = True
+        self.show_timestamp = True
+
+        self.user_color = QColor('#3399cc')
+        self.time_color = QColor('#94a1a7')
+        self.bg_color = QColor('#4a5153')
+        self.bg_alternate_color = QColor('#444b4d')
+        self.text_color = QColor('#FFFFFF')
+        self.separator_color = QColor('#333536')
+                
+        self.fm = None
+        
+        self.normFont = None
+        self.miniFont = None
+
+    def sizeHint (self, option, index):
+        '''Custom size calculation of our items'''
+        size = QStyledItemDelegate.sizeHint(self, option, index)
+        tweet = index.data(Qt.DisplayRole).toString()
+        #One time is enought sizeHint need to be fast
+        if self.fm == None:
+            self.fm = QFontMetrics(option.font)
+        height = self.fm.boundingRect(0,0,option.rect.width()-75,800, int(Qt.AlignTop) | int(Qt.AlignLeft) | int(Qt.TextWordWrap), tweet).height()
+        if height<16:
+            height=16        
+        return QSize(size.width(), height+44)
+        
+
+    def paint(self, painter, option, index):
+        '''Paint our tweet'''
+        self.fm = QFontMetrics(option.font)
+
+        model = index.model()
+        tweet = index.data(Qt.DisplayRole).toString()
+        
+        #Instantiate font only one time !
+        if self.normFont == None:
+            self.normFont = QFont(option.font)
+            self.miniFont = QFont(option.font)
+            self.miniFont.setPointSizeF(option.font.pointSizeF() * 0.80)            
+        
+        painter.save()
+        
+        # Draw alternate ?
+        if (index.row()%2)==0:
+            painter.fillRect(option.rect, self.bg_color)
+        else:
+            painter.fillRect(option.rect, self.bg_alternate_color)            
+
+        # highlight selected items
+        if option.state & QStyle.State_Selected: 
+            painter.fillRect(option.rect, option.palette.highlight());
+                    
+        # Draw icon
+        if self.show_avatar:
+            icon = index.data(Qt.DecorationRole).toPyObject();
+            if icon != None:
+                x1,y1,x2,y2 = option.rect.getCoords()
+                painter.drawPixmap(x1+10,y1+10,50,50,icon)
+                                                
+        # Draw tweet
+        painter.setPen(self.text_color)
+        new_rect = painter.drawText(option.rect.adjusted(int(self.show_avatar)*70,5,0,0),  int(Qt.AlignTop) | int(Qt.AlignLeft) | int(Qt.TextWordWrap), tweet); 
+                
+        # Draw Timeline
+        if self.show_timestamp:
+            time = index.data(Qt.ToolTipRole).toString();
+            painter.setFont(self.miniFont)
+            painter.setPen(self.time_color)
+            painter.drawText(option.rect.adjusted(70,10,-10,-9),  int(Qt.AlignBottom) | int(Qt.AlignRight), time);
+
+        # Draw screenname
+        if self.show_screenname:
+            screenname = index.data(SCREENNAMEROLE).toString();
+            painter.setFont(self.miniFont)
+            painter.setPen(self.user_color)
+            painter.drawText(option.rect.adjusted(70,10,-10,-9),  int(Qt.AlignBottom) | int(Qt.AlignLeft), screenname);
+
+        # Draw line
+        painter.setPen(self.separator_color)
+        x1,y1,x2,y2 = option.rect.getCoords()
+        painter.drawLine(x1,y2,x2,y2) 
+
+        painter.restore()
         
 class KhweetsView(QListView):
     ''' Model View '''
@@ -786,23 +974,45 @@ class KhweetsView(QListView):
         self.setWordWrap(True)
         self.refreshCustomDelegate()
         self.setEditTriggers(QAbstractItemView.SelectedClicked)
-        self.setSpacing(2)
+        self.setSpacing(0)
         self.setUniformItemSizes(False)
         self.setResizeMode(QListView.Adjust)
         #self.setViewMode(QListView.ListMode)
         self.setHorizontalScrollBarPolicy(Qt.ScrollBarAlwaysOff)
         self.setVerticalScrollBarPolicy(Qt.ScrollBarAlwaysOn)
+#        self.overShootMove = False
         #self.setWrapping(True)
         #self.setFlow(QListView.TopToBottom)
 #        self.setAlternatingRowColors(True)  
 #        self.setAlternatingRowColors(True)
 
+    #Work around for qt4.6 scrollarea bug which didn't work
+#    def event(self,anEvent):        
+#        if anEvent.type() == QEvent.Move:
+#            if not self.overShootMove:
+#                self.overShootMove = True
+#                r = QAbstractScrollArea.event(self,anEvent)
+#                self.overShootMove = False
+#                return r
+#        else:
+#            return QListView.event(self,anEvent)
+#            
+#    def setScrollPosition(self,point1,point2):
+#        self.overShootMove = True
+#        r = QAbstractScrollArea.setScrollPosition(self,point1,point2)
+#        self.overShootMove = False
+#        return r
+        
     def refreshCustomDelegate(self):
         theme = self.parent().settings.value('theme')
         if theme == KhweeteurPref.WHITETHEME:
             self.custom_delegate = WhiteCustomDelegate(self)
         elif theme == KhweeteurPref.DEFAULTTHEME:
             self.custom_delegate = DefaultCustomDelegate(self)
+        elif theme == KhweeteurPref.COOLWHITETHEME:
+            self.custom_delegate = CoolWhiteCustomDelegate(self)
+        elif theme == KhweeteurPref.COOLGRAYTHEME:
+            self.custom_delegate = CoolGrayCustomDelegate(self)
         else:
             self.custom_delegate = DefaultCustomDelegate(self)
         self.setItemDelegate(self.custom_delegate)
@@ -917,7 +1127,9 @@ class KhweetAction(QDialog):
 class KhweeteurPref(QMainWindow):
     DEFAULTTHEME = 'Default'
     WHITETHEME = 'White'
-    THEMES = [DEFAULTTHEME,WHITETHEME,]
+    COOLWHITETHEME = 'CoolWhite'
+    COOLGRAYTHEME = 'CoolGray'
+    THEMES = [DEFAULTTHEME, WHITETHEME, COOLWHITETHEME, COOLGRAYTHEME]
 
     def __init__(self, parent=None):
         QMainWindow.__init__(self,parent)
@@ -941,7 +1153,7 @@ class KhweeteurPref(QMainWindow):
         self.useNotification_value.setCheckState(self.settings.value("useNotification").toInt()[0])
         self.useSerialization_value.setCheckState(self.settings.value("useSerialization").toInt()[0])
         self.useBitly_value.setCheckState(self.settings.value("useBitly").toInt()[0])
-        if self.settings.value("theme"):
+        if not self.settings.value("theme"):
             self.settings.setValue("theme",'Default')
         self.theme_value.setCurrentIndex(self.THEMES.index(self.settings.value("theme").toString()))
 
@@ -1189,6 +1401,10 @@ class KhweeteurWin(QMainWindow):
         self.tweetsModel.display_avatar = self.settings.value("displayAvatar").toBool()
             
         QTimer.singleShot(200, self.justAfterInit)
+
+    def closeEvent(self,widget,*args):
+        for win in self.search_win:
+            win.close()
         
     def justAfterInit(self):
         from nwmanager import NetworkManager
@@ -1317,7 +1533,7 @@ class KhweeteurWin(QMainWindow):
                             api.SetUserAgent('Khweeteur/%s' % (__version__))
                             api.CreateFriendship(user_screenname)
                             self.notifications.info('You are now following %s on Twitter' % (user_screenname))
-                    except (twitter.TwitterError,StandardError,urllib2.HTTPError, urllib2.httplib.BadStatusLine),e:
+                    except (twitter.TwitterError,StandardError,urllib2.HTTPError, urllib2.httplib.BadStatusLine, socket.timeout, socket.sslerror),e:
                         if type(e)==twitter.TwitterError:
                             self.notifications.warn('Add %s to friendship failed on Twitter : %s' %(user_screenname,e.message))
                             print e.message
@@ -1333,7 +1549,7 @@ class KhweeteurWin(QMainWindow):
                             api.SetUserAgent('Khweeteur/%s' % (__version__))    
                             api.CreateFriendship(user_screenname)
                             self.notifications.info('You are now following %s on Identi.ca' % (user_screenname))
-                    except (twitter.TwitterError,StandardError,urllib2.HTTPError, urllib2.httplib.BadStatusLine),e:
+                    except (twitter.TwitterError,StandardError,urllib2.HTTPError, urllib2.httplib.BadStatusLine, socket.timeout, socket.sslerror),e:
                         if type(e)==twitter.TwitterError:
                             self.notifications.warn('Add %s to friendship failed on Identi.ca : %s' %(user_screenname,e.message))
                             print e.message
@@ -1361,7 +1577,7 @@ class KhweeteurWin(QMainWindow):
                             api.SetUserAgent('Khweeteur/%s' % (__version__))
                             api.DestroyFriendship(user_screenname)
                             self.notifications.info('You didn\'t follow %s anymore on Twitter' % (user_screenname))
-                    except (twitter.TwitterError,StandardError,urllib2.HTTPError, urllib2.httplib.BadStatusLine),e:
+                    except (twitter.TwitterError,StandardError,urllib2.HTTPError, urllib2.httplib.BadStatusLine, socket.timeout, socket.sslerror),e:
                         if type(e)==twitter.TwitterError:
                             self.notifications.warn('Remove %s to friendship failed on Twitter : %s' %(user_screenname,e.message))
                             print e.message
@@ -1377,7 +1593,7 @@ class KhweeteurWin(QMainWindow):
                             api.SetUserAgent('Khweeteur/%s' % (__version__))    
                             api.DestroyFriendship(user_screenname)
                             self.notifications.info('You didn\'t follow %s anymore on Identi.ca' % (user_screenname))
-                    except (twitter.TwitterError,StandardError,urllib2.HTTPError, urllib2.httplib.BadStatusLine),e:
+                    except (twitter.TwitterError,StandardError,urllib2.HTTPError, urllib2.httplib.BadStatusLine, socket.timeout, socket.sslerror),e:
                         if type(e)==twitter.TwitterError:
                             self.notifications.warn('Remove %s to friendship failed on Identi.ca : %s' %(user_screenname,e.message))
                             print e.message
@@ -1402,7 +1618,7 @@ class KhweeteurWin(QMainWindow):
                         api.SetUserAgent('Khweeteur/%s' % (__version__))
                         api.PostRetweet(tweetid)
                         self.notifications.info('Retweet send to Twitter')
-                except (twitter.TwitterError,StandardError,urllib2.HTTPError, urllib2.httplib.BadStatusLine),e:
+                except (twitter.TwitterError,StandardError,urllib2.HTTPError, urllib2.httplib.BadStatusLine, socket.timeout, socket.sslerror),e:
                     if type(e)==twitter.TwitterError:
                         self.notifications.warn('Retweet to twitter failed : '+(e.message))
                         print e.message
@@ -1418,7 +1634,7 @@ class KhweeteurWin(QMainWindow):
                         api.SetUserAgent('Khweeteur/%s' % (__version__))    
                         api.PostRetweet(tweetid)
                         self.notifications.info('Retweet send to Identi.ca')
-                except (twitter.TwitterError,StandardError,urllib2.HTTPError, urllib2.httplib.BadStatusLine),e:
+                except (twitter.TwitterError,StandardError,urllib2.HTTPError, urllib2.httplib.BadStatusLine, socket.timeout, socket.sslerror),e:
                     if type(e)==twitter.TwitterError:
                         self.notifications.warn('Retweet to identi.ca failed : '+(e.message))
                         print e.message
@@ -1444,7 +1660,7 @@ class KhweeteurWin(QMainWindow):
                         api.DestroyStatus(tweetid)
                         self.tweetsModel.destroyStatus(index)
                         self.notifications.info('Status destroyed on Twitter')
-                except (twitter.TwitterError,StandardError,urllib2.HTTPError, urllib2.httplib.BadStatusLine),e:
+                except (twitter.TwitterError,StandardError,urllib2.HTTPError, urllib2.httplib.BadStatusLine, socket.timeout, socket.sslerror),e:
                     if type(e)==twitter.TwitterError:
                         self.notifications.warn('Destroy status from twitter failed : '+(e.message))
                         print e.message
@@ -1461,7 +1677,7 @@ class KhweeteurWin(QMainWindow):
                         api.DestroyStatus(tweetid)
                         self.tweetsModel.destroyStatus(index)
                         self.notifications.info('Status destroyed on Identi.ca')
-                except (twitter.TwitterError,StandardError,urllib2.HTTPError, urllib2.httplib.BadStatusLine),e:
+                except (twitter.TwitterError,StandardError,urllib2.HTTPError, urllib2.httplib.BadStatusLine, socket.timeout, socket.sslerror),e:
                     if type(e)==twitter.TwitterError:
                         self.notifications.warn('Destroy status from identi.ca failed : '+(e.message))
                         print e.message
@@ -1675,7 +1891,6 @@ class Khweeteur(QApplication):
                 else:
                     QMessageBox.question(None,
                     "Khweeteur Crash Report",
-                    "%s" % the_page,
                     QMessageBox.Close)
                     return False
             try:
@@ -1688,9 +1903,9 @@ class Khweeteur(QApplication):
         self.dbus_object.attach_win(self.win)
         self.crash_report()
         self.win.show()
-        sys.exit(self.exec_())
+        
 #        self.exec_()
 
 if __name__ == '__main__':
-    Khweeteur()
+    sys.exit(Khweeteur().exec_())
 
